pub struct ArgsSchema {
pub description: String,
}Expand description
Opaque positional-arg schema. v1 placeholder — description string. A future slice can grow this to a typed validator (number of required args, whether trailing args are allowed, etc.).
Fields
description: StringTrait Implementations
Sourceimpl Clone for ArgsSchema
impl Clone for ArgsSchema
Sourcefn clone(&self) -> ArgsSchema
fn clone(&self) -> ArgsSchema
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ArgsSchema
impl RefUnwindSafe for ArgsSchema
impl Send for ArgsSchema
impl Sync for ArgsSchema
impl Unpin for ArgsSchema
impl UnsafeUnpin for ArgsSchema
impl UnwindSafe for ArgsSchema